@@ -1,7 +1,7 @@
 # ABSTRACT: take structured address data and format it according to the various global/country rules
 
 package Geo::Address::Formatter;
-$Geo::Address::Formatter::VERSION = '1.71';
+$Geo::Address::Formatter::VERSION = '1.72';
 use strict;
 use warnings;
 use feature qw(say);
@@ -13,8 +13,8 @@ use File::Find::Rule;
 use List::Util qw(first);
 use Scalar::Util qw(looks_like_number);
 use Text::Hogan::Compiler;
-use Try::Tiny;
-use YAML qw(Load LoadFile);
+use Try::Catch;
+use YAML::XS qw(LoadFile);
 use utf8;
 
 my $THC = Text::Hogan::Compiler->new;
@@ -673,7 +673,7 @@ Geo::Address::Formatter - take structured address data and format it according t
 
 =head1 VERSION
 
-version 1.71
+version 1.72
 
 =head1 SYNOPSIS
 
